/*  Glimmer - colors.h
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU LiGeneral Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _COLORS_H_
#define _COLORS_H_

#ifdef __cplusplus
extern "C" {
#endif

static char *editor_color_names[] =
{
   "string",
   "char",
   "char_string",
   "keyword",
   "comment",
   "preprocessor",
   "data_type",
   "function",
   "macro",
   "variable",
   "symbol",
   "operator",
   "punctuation",
   "decimal",
   "hexidecimal",
   "octal",
   "white",
   "black",
   "gray",
   "blue",
   "dark_blue",
   "red",
   "dark_red",
   "green",
   "dark_green",
   "cyan",
   "magenta",
   "yellow",
   "orange",
   "default"
};

#ifdef __cplusplus
}
#endif

#endif
